@@ -4,11 +4,21 @@ class ConfigurationException(Exception):
 
 # Request related exceptions
 class BaseRequestException(Exception):
-    def __init__(self, response, message=None, error=None, error_description=None):
+    def __init__(
+        self,
+        response,
+        message=None,
+        error=None,
+        errors=None,
+        error_description=None,
+        code=None,
+    ):
         super(BaseRequestException, self).__init__(message)
 
         self.message = message
         self.error = error
+        self.errors = errors
+        self.code = code
         self.error_description = error_description
         self.extract_and_set_response_related_data(response)
 
@@ -18,8 +28,12 @@ class BaseRequestException(Exception):
         try:
             response_json = response.json()
             self.message = response_json.get("message")
+            self.errors = response_json.get("errors")
+            self.code = response_json.get("code")
         except ValueError:
             self.message = None
+            self.errors = None
+            self.code = None
 
         headers = response.headers
         self.request_id = headers.get("X-Request-ID")
@@ -31,9 +45,15 @@ class BaseRequestException(Exception):
         if self.request_id is not None:
             exception += ", request_id=%s" % self.request_id
 
+        if self.code is not None:
+            exception += ", code=%s" % self.code
+
         if self.error is not None:
             exception += ", error=%s" % self.error
 
+        if self.errors is not None:
+            exception += ", errors=%s" % self.errors
+
         if self.error_description is not None:
             exception += ", error_description=%s" % self.error_description
 
